SelectorErrorCode

Struct SelectorErrorCode 

pub struct SelectorErrorCode { /* private fields */ }
Describes an error code referencing a segment selector.

Implementations

Source

impl SelectorErrorCode

pub const fn new(value: u64) -> Option<Self>

Create a SelectorErrorCode. Returns None is any of the reserved bits (16-64) are set.

pub const fn new_truncate(value: u64) -> Self

Create a new SelectorErrorCode dropping any reserved bits (16-64).

pub fn external(&self) -> bool

If true, indicates that the exception occurred during delivery of an event external to the program, such as an interrupt or an earlier exception.

pub fn descriptor_table(&self) -> DescriptorTable

The descriptor table this error code refers to.

pub fn index(&self) -> u64

The index of the selector which caused the error.

pub fn is_null(&self) -> bool

If true, the #SS or #GP has returned zero as opposed to a SelectorErrorCode.